import { 
  select,
  json,
  scaleOrdinal,
  range,
  schemeSpectral
} from 'd3';
import { colorLegend } from './colorLegend';

const svg = select('svg').style('background-color', '#f7ef8f');
const width  = +svg.attr('width');
const height = +svg.attr('height');

const midiFileColorLegendG = svg.append('g')
    .attr('transform', `translate(50,40)`);
const colorScale = scaleOrdinal();

const trackColorLegendG = svg.append('g')
    .attr('transform', `translate(50,200)`);

let filesAndTracks;
let selectedFile;
let selectedTrack;

const midiFileOnClick = d => {
  selectedFile = d;
  const tracks = getTracks();
  selectedTrack = filesAndTracks[selectedFile][0];
  renderMidifiles();
  renderTracks();
};

const trackOnClick = d => {
  selectedTrack = d;
  renderTracks();
};

const getTracks = () => {
  return filesAndTracks[selectedFile];
}

const renderMidifiles = () => {
  colorScale
    .domain(range(filesAndTracks.length))
    .range(schemeSpectral[colorScale.domain().length]);
  
  midiFileColorLegendG.call(colorLegend, {
    colorScale,
    circleRadius: 8,
    spacing: 25,
    textOffset: 15,
    backgroundRectWidth: 100,
    onClick: midiFileOnClick,
    selectedColorValue: selectedFile
  });
}

const renderTracks = () => {
  const tracks = getTracks();
  const nn = tracks.length;
  const trackColorScale = scaleOrdinal()
    .domain(tracks)
    .range([0, 255]);
  
  trackColorLegendG.call(colorLegend, {
    colorScale: trackColorScale,
    circleRadius: 8,
    spacing: 25,
    textOffset: 12,
    backgroundRectWidth: 100,
    onClick: trackOnClick,
    selectedColorValue: selectedTrack
  });
}

const render = () => {
  renderMidifiles();
  renderTracks();
};

json('https://vizhub.com/rubens2005/datasets/songs.csv').then(data => {
  const keys = Object.keys(data);
  filesAndTracks = keys.map(d => Object.keys(data[d].notas));
  selectedFile = 2;
  selectedTrack = filesAndTracks[selectedFile][0];
  render();
});